@@ -1,11 +1,11 @@
 import datetime
 
 from typing import Optional, Dict, List
-from e2b.sandbox.mcp import McpServer
+from e2b.api.client.types import UNSET
 from packaging.version import Version
 from typing_extensions import Unpack
 
-from e2b.sandbox.sandbox_api import SandboxInfo, SandboxMetrics, SandboxQuery
+from e2b.sandbox.sandbox_api import SandboxInfo, SandboxMetrics, SandboxQuery, McpServer
 from e2b.sandbox.main import SandboxBase
 from e2b.exceptions import TemplateException, SandboxException, NotFoundException
 from e2b.api import ApiClient, SandboxCreateResponse
@@ -165,7 +165,7 @@ class SandboxApi(SandboxBase):
                     metadata=metadata or {},
                     timeout=timeout,
                     env_vars=env_vars or {},
-                    mcp=mcp,
+                    mcp=mcp or UNSET,
                     secure=secure,
                     allow_internet_access=allow_internet_access,
                 ),
