@@ -4,6 +4,7 @@ from pathlib import Path
 
 from httpx import Limits
 
+from e2b.exceptions import BuildException
 from e2b.template.consts import STACK_TRACE_DEPTH, RESOLVE_SYMLINKS
 from e2b.template.dockerfile_parser import parse_dockerfile
 from e2b.template.readycmd import ReadyCmd
@@ -121,6 +122,7 @@ class TemplateBuilder:
         path: Union[Union[str, Path], List[Union[str, Path]]],
         force: bool = False,
         recursive: bool = False,
+        user: Optional[str] = None,
     ) -> "TemplateBuilder":
         """
         Remove files or directories in the template.
@@ -128,12 +130,14 @@ class TemplateBuilder:
         :param path: File(s) or directory path(s) to remove
         :param force: Force removal without prompting
         :param recursive: Remove directories recursively
+        :param user: User to run the command as
 
         :return: `TemplateBuilder` class
 
         Example
         ```python
         template.remove('/tmp/cache', recursive=True, force=True)
+        template.remove('/tmp/cache', recursive=True, force=True, user='root')
         ```
         """
         paths = [path] if isinstance(path, (str, Path)) else path
@@ -145,11 +149,15 @@ class TemplateBuilder:
         args.extend([str(p) for p in paths])
 
         return self._template._run_in_new_stack_trace_context(
-            lambda: self.run_cmd(" ".join(args))
+            lambda: self.run_cmd(" ".join(args), user=user)
         )
 
     def rename(
-        self, src: Union[str, Path], dest: Union[str, Path], force: bool = False
+        self,
+        src: Union[str, Path],
+        dest: Union[str, Path],
+        force: bool = False,
+        user: Optional[str] = None,
     ) -> "TemplateBuilder":
         """
         Rename or move a file or directory in the template.
@@ -157,12 +165,14 @@ class TemplateBuilder:
         :param src: Source path
         :param dest: Destination path
         :param force: Force rename without prompting
+        :param user: User to run the command as
 
         :return: `TemplateBuilder` class
 
         Example
         ```python
         template.rename('/tmp/old.txt', '/tmp/new.txt')
+        template.rename('/tmp/old.txt', '/tmp/new.txt', user='root')
         ```
         """
         args = ["mv", str(src), str(dest)]
@@ -170,19 +180,21 @@ class TemplateBuilder:
             args.append("-f")
 
         return self._template._run_in_new_stack_trace_context(
-            lambda: self.run_cmd(" ".join(args))
+            lambda: self.run_cmd(" ".join(args), user=user)
         )
 
     def make_dir(
         self,
         path: Union[Union[str, Path], List[Union[str, Path]]],
         mode: Optional[int] = None,
+        user: Optional[str] = None,
     ) -> "TemplateBuilder":
         """
         Create directory(ies) in the template.
 
         :param path: Directory path(s) to create
         :param mode: Directory permissions in octal format (e.g., 0o755)
+        :param user: User to run the command as
 
         :return: `TemplateBuilder` class
 
@@ -190,6 +202,7 @@ class TemplateBuilder:
         ```python
         template.make_dir('/app/data', mode=0o755)
         template.make_dir(['/app/logs', '/app/cache'])
+        template.make_dir('/app/data', mode=0o755, user='root')
         ```
         """
         path_list = [path] if isinstance(path, (str, Path)) else path
@@ -199,28 +212,39 @@ class TemplateBuilder:
         args.extend([str(p) for p in path_list])
 
         return self._template._run_in_new_stack_trace_context(
-            lambda: self.run_cmd(" ".join(args))
+            lambda: self.run_cmd(" ".join(args), user=user)
         )
 
     def make_symlink(
-        self, src: Union[str, Path], dest: Union[str, Path]
+        self,
+        src: Union[str, Path],
+        dest: Union[str, Path],
+        user: Optional[str] = None,
+        force: bool = False,
     ) -> "TemplateBuilder":
         """
         Create a symbolic link in the template.
 
         :param src: Source path (target of the symlink)
         :param dest: Destination path (location of the symlink)
+        :param user: User to run the command as
+        :param force: Force symlink without prompting
 
         :return: `TemplateBuilder` class
 
         Example
         ```python
         template.make_symlink('/usr/bin/python3', '/usr/bin/python')
+        template.make_symlink('/usr/bin/python3', '/usr/bin/python', user='root')
+        template.make_symlink('/usr/bin/python3', '/usr/bin/python', force=True)
         ```
         """
-        args = ["ln", "-s", str(src), str(dest)]
+        args = ["ln", "-s"]
+        if force:
+            args.append("-f")
+        args.extend([str(src), str(dest)])
         return self._template._run_in_new_stack_trace_context(
-            lambda: self.run_cmd(" ".join(args))
+            lambda: self.run_cmd(" ".join(args), user=user)
         )
 
     def run_cmd(
@@ -371,11 +395,14 @@ class TemplateBuilder:
             lambda: self.run_cmd(" ".join(args), user="root" if g else None)
         )
 
-    def apt_install(self, packages: Union[str, List[str]]) -> "TemplateBuilder":
+    def apt_install(
+        self, packages: Union[str, List[str]], no_install_recommends: bool = False
+    ) -> "TemplateBuilder":
         """
         Install system packages using apt-get.
 
         :param packages: Package name(s) to install
+        :param no_install_recommends: Whether to install recommended packages
 
         :return: `TemplateBuilder` class
 
@@ -392,18 +419,56 @@ class TemplateBuilder:
             lambda: self.run_cmd(
                 [
                     "apt-get update",
-                    f"DEBIAN_FRONTEND=noninteractive DEBCONF_NOWARNINGS=yes apt-get install -y --no-install-recommends {' '.join(packages)}",
+                    f"DEBIAN_FRONTEND=noninteractive DEBCONF_NOWARNINGS=yes apt-get install -y {'--no-install-recommends ' if no_install_recommends else ''}{' '.join(packages)}",
                 ],
                 user="root",
             )
         )
 
+    def beta_add_mcp_server(self, servers: Union[str, List[str]]) -> "TemplateBuilder":
+        """
+        Install MCP servers using mcp-gateway.
+
+        Note: Requires a base image with mcp-gateway pre-installed (e.g., mcp-gateway).
+
+        :param servers: MCP server name(s)
+
+        :return: `TemplateBuilder` class
+
+        Example
+        ```python
+        template.beta_add_mcp_server('exa')
+        template.beta_add_mcp_server(['brave', 'firecrawl', 'duckduckgo'])
+        ```
+        """
+        if self._template._base_template != "mcp-gateway":
+            caller_frame = get_caller_frame(STACK_TRACE_DEPTH - 1)
+            stack_trace = None
+            if caller_frame is not None:
+                stack_trace = TracebackType(
+                    tb_next=None,
+                    tb_frame=caller_frame,
+                    tb_lasti=caller_frame.f_lasti,
+                    tb_lineno=caller_frame.f_lineno,
+                )
+            raise BuildException(
+                "MCP servers can only be added to mcp-gateway template"
+            ).with_traceback(stack_trace)
+
+        if isinstance(servers, str):
+            servers = [servers]
+
+        return self._template._run_in_new_stack_trace_context(
+            lambda: self.run_cmd(f"mcp-gateway pull {' '.join(servers)}", user="root")
+        )
+
     def git_clone(
         self,
         url: str,
         path: Optional[Union[str, Path]] = None,
         branch: Optional[str] = None,
         depth: Optional[int] = None,
+        user: Optional[str] = None,
     ) -> "TemplateBuilder":
         """
         Clone a git repository into the template.
@@ -412,6 +477,7 @@ class TemplateBuilder:
         :param path: Destination path for the clone
         :param branch: Branch to clone
         :param depth: Clone depth for shallow clones
+        :param user: User to run the command as
 
         :return: `TemplateBuilder` class
 
@@ -419,6 +485,7 @@ class TemplateBuilder:
         ```python
         template.git_clone('https://github.com/user/repo.git', '/app/repo')
         template.git_clone('https://github.com/user/repo.git', branch='main', depth=1)
+        template.git_clone('https://github.com/user/repo.git', '/app/repo', user='root')
         ```
         """
         args = ["git", "clone", url]
@@ -430,7 +497,7 @@ class TemplateBuilder:
         if path:
             args.append(str(path))
         return self._template._run_in_new_stack_trace_context(
-            lambda: self.run_cmd(" ".join(args))
+            lambda: self.run_cmd(" ".join(args), user=user)
         )
 
     def set_envs(self, envs: Dict[str, str]) -> "TemplateBuilder":
@@ -717,11 +784,11 @@ class TemplateBase:
             lambda: self.from_image(f"debian:{variant}")
         )
 
-    def from_ubuntu_image(self, variant: str = "lts") -> TemplateBuilder:
+    def from_ubuntu_image(self, variant: str = "latest") -> TemplateBuilder:
         """
         Start template from an Ubuntu base image.
 
-        :param variant: Ubuntu image variant (default: 'lts')
+        :param variant: Ubuntu image variant (default: 'latest')
 
         :return: `TemplateBuilder` class
 
